Stores
======

.. autosummary::
   :nosignatures:

   custodia.store.sqlite.SqliteStore
   custodia.store.etcdstore.EtcdStore
   custodia.store.encgen.EncryptedOverlay

.. autoclass:: custodia.store.sqlite.SqliteStore
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.store.etcdstore.EtcdStore
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.store.encgen.EncryptedOverlay
    :members:
    :undoc-members:
    :show-inheritance:
